@@ -13,7 +13,7 @@ class Command(BasePassManageCommand):
         super().run_from_argv(argv)
 
         # Just pass every argument to the origin tox CLI:
-        verbose_check_call(sys.executable, '-m', 'tox', *argv[2:])
+        verbose_check_call(sys.executable, '-m', 'tox', *argv[2:], exit_on_error=True)
 
         coverage_combine_report(verbose=True)
 
